﻿using GanttPrototype.Data;
using GanttPrototype.Model;
using Infragistics;
using Infragistics.Controls.Schedules;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace GanttPrototype.ViewModels
{
    public class MainWindowViewModel: DependencyObject
    {
        private Project _data;
        private ProjectViewSettings _viewSettings;

        public MainWindowViewModel()
        {
            InitData();

            _viewSettings = new ProjectViewSettings()
            {
                Timescale = InitTimescale()
            };
        }

        public Project Data
        {
            get { return _data; }
        }

        public DateRange DateRange
        {
            // ### IT SEEMS THIS DATE RANGE IS BEING IGNORED ###
            get { return new DateRange(DateTime.Today.AddHours(13), DateTime.Today.AddHours(16)); }
        }

        public ProjectViewSettings ViewSettings
        {
            get { return _viewSettings; }
        }

        private Timescale InitTimescale()
        {
            Timescale result = new Timescale();

            result.Bands.Add(new TimescaleBand() { Unit = TimescaleUnit.Days });
            result.Bands.Add(new TimescaleBand() { Unit = TimescaleUnit.Minutes, UnitCount = 30, DisplayFormat = "HH:mm" });

            return result;
        }

        /// <summary>Generate demo data.</summary>
        private void InitData()
        {
            _data = new Project();

            List<Batch> batches;
            List<DownTime> downTimes;

            DataGenerator.Generate(out batches, out downTimes);

            List<TaskViewModel> taskViewModels = CreateTaskViewModels(batches, downTimes);

            CreateTasks(taskViewModels);
        }

        private List<TaskViewModel> CreateTaskViewModels(List<Batch> batches, List<DownTime> downTimes)
        {
            List<TaskViewModel> taskViewModels = new List<TaskViewModel>();

            foreach (Batch batch in batches)
                taskViewModels.Add(new TaskViewModel(batch));

            foreach (DownTime downTime in downTimes)
                taskViewModels.Add(new TaskViewModel(downTime));

            return taskViewModels;
        }

        /// <summary>Creates the actual Gantt tasks.</summary>
        private void CreateTasks(List<TaskViewModel> taskViewModels)
        {
            foreach (TaskViewModel taskViewModel in taskViewModels)
            {
                ProjectTask task = new ProjectTask
                {
                    //TaskName = taskViewModel.TaskExecutor,
                    TaskName = taskViewModel.Label,
                    IsManual = true,
                    Start = taskViewModel.StartTime.ToUniversalTime(),
                    Duration = taskViewModel.Duration,
                    DataItem = taskViewModel
                };

                _data.RootTask.Tasks.Add(task);
            }
        }
    }
}
