﻿using GanttPrototype.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Media;

namespace GanttPrototype.ViewModels
{
    public class TaskViewModel
    {
        private Batch _batch = null;
        private DownTime _downTime = null;

        public TaskViewModel(Batch batch)
        {
            if (batch == null)
                throw new ArgumentNullException("batch");

            _batch = batch;
        }

        public TaskViewModel(DownTime downTime)
        {
            if (downTime == null)
                throw new ArgumentNullException("downTime");

            _downTime = downTime;
        }

        public bool IsBatch { get { return _batch != null; } }

        public bool IsDownTime { get { return _downTime != null; } }

        public DateTime StartTime
        {
            get { return IsBatch ? _batch.StartTime : _downTime.StartTime; }
        }

        public TimeSpan Duration
        {
            get { return IsBatch ? _batch.Duration : _downTime.Duration; }
        }

        public string Label
        {
            get { return IsBatch ? _batch.Info : _downTime.Reason; }
        }

        public string TaskExecutor
        {
            get { return IsBatch ? _batch.Executor.Name : _downTime.Target.Name; }
        }

        public string ToolTip
        {
            get { return IsBatch ? string.Format("{0} {1}", _batch.Amount, _batch.Article.Name) : _downTime.Feedback; }
        }

        public Brush Fill
        {
            get { return IsDownTime ? new SolidColorBrush(Colors.Black) : new SolidColorBrush(Colors.Gold); }
        }

        public Brush Border
        {
            get { return IsDownTime ? new SolidColorBrush(Colors.Black) : new SolidColorBrush(Colors.Goldenrod); }
        }

        public double BorderThickness
        {
            get { return 1; }
        }

        public DoubleCollection BorderDashArray
        {
            //get { return new DoubleCollection(new double[] { 3, 2 }); }
            get { return new DoubleCollection(); }
        }
    }
}
